# CNC Machining Overview

The CNC (Computer Numerical Control) machine used in this lab is a large-format router capable of cutting full-sized wooden sheets using a 6mm cutting tool. It operates through instructions received from a computer, translating CAD designs into toolpaths that direct the cutting head’s movement, speed, and depth. These toolpaths ensure precision and repeatability by controlling the spindle’s rotation (RPM), feed rate (inches per minute), and cut depth.

**Functionality Summary:**
- Receives commands from a computer.
- Follows toolpaths derived from CAD designs.
- Cuts materials with controlled speed and depth.
- Used for manufacturing wooden structures, furniture, and fit-based assemblies.

![Insert image of CNC machine here](insert_image_path_here)

---

#### Video - Full Explanation

The video below showcases how the system works with explanation.

<div style="text-align: center;">
</div>
<div style="text-align: center;">
<iframe src="https://drive.google.com/file/d/1VN3HspvUYQrikhdPZ01qQcaQPyVWSw2N/preview" width="640" height="480" allow="autoplay"></iframe>
</div>
<br>

---

#### Safety Requirements

Strict safety protocols must be followed when operating the CNC machine:

- **Eye Protection:** Safety glasses must be worn to shield eyes from debris.
- **Face Mask:** Use a face mask to prevent inhalation of fine dust particles.
- **Clothing:** Avoid loose garments, jewelry, or accessories that may get caught.
- **Work Area Inspection:** Check the machine and all tools before starting.
- **Clean Environment:** Keep the machine and surroundings clear of clutter before and after use.
- **Hearing Protection:** Wear ear protection to prevent hearing damage.
- **Emergency Stop:** Be aware of the emergency stop button location.
- **Operational Distance:** Stay a safe distance from the machine while in use.
- **Handling Materials:** Never attempt to remove or adjust material while the machine is active.
- **Supervision:** Machine operation must always be monitored during cutting.

![Insert image of safety gear or workspace here](insert_image_path_here)

---

#### Design Requirements

When designing for CNC cutting:
- Maintain at least **20 mm gap** between each design part.
- Keep designs at least **30 mm away** from each sheet corner.
- Ensure holes in your design are **larger than the drill bit’s diameter (6mm)** so they can be cut cleanly.
- Select drill bits **longer than your material’s thickness** for full cuts.
- Export files in **DXF format** for compatibility.
- Double-check that the design size suits the tool (e.g., drill bit not larger than the smallest detail).

---

#### Debris Management

The CNC machine includes a built-in vacuum system that removes debris generated during cutting. This ensures:

  <p align="center">
    <img src="cnc-images/debris.jpg" style="border: 2px solid black;" />
    </p>

  <iframe src="https://giphy.com/embed/3apHw0wrSauGTP7yLf" width="480" height="269" style="" frameBorder="0" class="giphy-embed" allowFullScreen></iframe><p><a href="https://giphy.com/gifs/3apHw0wrSauGTP7yLf"></a></p>

- Cleaner work environment.
- Improved visibility and safety.
- Better cut accuracy and finish.

---

#### Importance of Dogbones

  <p align="center">
    <img src="cnc-images/dogbone.png" style="border: 2px solid black;" />
    </p>

  <p align="center">
    <img src="cnc-images/dogbone2.png" style="border: 2px solid black;" />
    </p>

  <iframe src="https://giphy.com/embed/Or8eV6iyuXgA9vTCIR" width="270" height="480" style="" frameBorder="0" class="giphy-embed" allowFullScreen></iframe><p><a href="https://giphy.com/gifs/Or8eV6iyuXgA9vTCIR"></a></p>

  <iframe src="https://giphy.com/embed/5jqEdWh3tQpRXeuB7w" width="480" height="269" style="" frameBorder="0" class="giphy-embed" allowFullScreen></iframe><p><a href="https://giphy.com/gifs/5jqEdWh3tQpRXeuB7w"></a></p>

Due to the round shape of the cutting tool, internal corners in wooden joints are not naturally square. Adding **dogbone fillets** to these corners allows parts to fit tightly and accurately in press-fit constructions.

---

#### Material Alignment and Sacrificial Sheet

Proper material positioning is crucial to cut accuracy. A **sacrificial sheet** is placed under the cutting material to:
- Prevent damage to the CNC bed.
- Allow cuts to go slightly deeper than the material thickness.
- Help hold the material in place with screws.

**Tips for Alignment:**
- Max sheet size: 2440 x 1220 x 12 mm (L x W x T).
- If the sheet is curved, place the concave side down.
- Secure with screws placed within 20 mm of the corners and across the center.

---

#### Materials Used

Two materials are commonly available:

| Material                     | Characteristics                                |
|-----------------------------|-------------------------------------------------|
| MDF (Medium-Density Fiberboard) | - Smooth surface<br>- Easy to machine<br>- Less durable |
| Plywood                     | - Layered structure<br>- Stronger and more resilient<br>- Harder to cut cleanly |

  <body>
        <div class="row">
            <div class="column">
                <img src="cnc-images/mdf.jpeg" alt="Image 1">
                <p class="caption">MDF Wood</p>
            </div>
            <div class="column">
                <img src="cnc-images/plywood.jpeg" alt="Image 2">
                <p class="caption">Plywood Wood</p>
            </div>
        </div>
  </body>

Cutting tests were conducted using MDF, optimizing speed and feed rate for best results.

---

#### Machine Alignment

Machine calibration is required before each cutting job. For this CNC machine:

- **Z-axis calibration** is automated.
- A metal plate and wire clip are used. Once the drill touches the plate, an electrical signal finalizes the zero position.
- Regular checks are needed for worn parts and tool integrity.

<body>
    <div class="row">
        <div class="column">
            <img src="cnc-images/metal.png" alt="Image 1">
            <p class="caption">MDF Wood</p>
        </div>
        <div class="column">
            <img src="cnc-images/clip.png" alt="Image 2">
            <p class="caption">Plywood Wood</p>
        </div>
    </div>
</body>

---

#### Drill Bit Selection Guidance

Choosing the right drill bit (end mill) is essential for clean, efficient cuts and depends on your material and the operation:

- **Bit Diameter:**
  - 6mm (default) is versatile for general cutting.
  - Use smaller bits (e.g., 3mm) for detailed work.
  - Larger bits (e.g., 12mm) for faster rough cuts on thicker materials.

- **Upcut Bit:**
  - Best for fast chip removal.
  - Leaves a rough top surface but clean bottom.
  - Good for deeper cuts.

- **Downcut Bit:**
  - Pushes fibers down.
  - Leaves a smooth top surface.
  - Good for thinner materials or laminated surfaces.

- **Compression Bit:**
  - Combines upcut and downcut features.
  - Smooth on both sides.
  - Ideal for plywood or double-sided finish materials.

  <body>
      <div class="row">
          <div class="column">
              <img src="cnc-images/drill.png" alt="Image 1">
              <p class="caption">MDF Wood</p>
          </div>
          <div class="column">
              <img src="cnc-images/drill2.png" alt="Image 2">
              <p class="caption">Plywood Wood</p>
          </div>
      </div>
  </body>

---

#### Speed & Feed

Proper speed and feed rate settings are critical for effective cuts:

  <p align="center">
    <img src="cnc-images/feed.jpg" style="border: 2px solid black;" />
  </p>

- **Speed (RPM):** Determines how fast the tool rotates.
- **Feed Rate (in/min):** Determines how fast the tool moves across the material.

For MDF using a 6mm tool:
- Optimal Speed: 8000 RPM
- Feed Rate: 80 in/min (can vary based on tool condition and material)

Monitor chip formation and surface quality during tests to fine-tune settings.

---

#### Tips to Reduce Material Waste

  <p align="center">
    <img src="cnc-images/material.png" style="border: 2px solid black;" />
    </p>

- **Group Parts Efficiently:** Nest your parts close together in CAD to use the least amount of space. [20mm space]
- **Use Off-Cuts:** Save and reuse unused areas of the sheet for future small projects or test cuts.
- **Add Labels:** Include engraved labels to organize parts and reduce re-cuts.
- **Test on Scrap:** Run test cuts on scrap wood or corners before running the full job.
- **Minimize Tabs:** Use just enough tabs to hold parts in place without excess material.

---

#### CNC Cutting Process

This section outlines the full workflow for using the CNC machine, from preparation to final cutting.

---

#### 1. Preparation

  <iframe src="https://giphy.com/embed/3apHw0wrSauGTP7yLf" width="480" height="269" style="" frameBorder="0" class="giphy-embed" allowFullScreen></iframe><p><a href="https://giphy.com/gifs/3apHw0wrSauGTP7yLf"></a></p>

- Remove debris and previous sheets using a vacuum.
- Unscrew and clear the CNC bed.
- Place the new sheet (MDF or Plywood).
- Adjust the sheet if bent; curve should face up with the middle touching the base.
- Fasten using screws placed within 20 mm from the edges.
  - Use a minimum of 8 screws for secure attachment.

  <p align="center">
    <img src="cnc-images/screw.png" style="border: 2px solid black;" />
    </p>

  <p align="center">
    <img src="cnc-images/screw2.png" style="border: 2px solid black;" />
    </p>

  <p align="center">
    <img src="cnc-images/sheet2.png" style="border: 2px solid black;" />
    </p>

---

#### 2. VCarve PRO Setup

- Export the design as a **DXF** file.
- Send the file to: `fablabbh.share@gmail.com`
- Open the file in **VCarve PRO**.
- Add a **30 mm offset** around the perimeter to avoid bolts.
  
  <p align="center">
    <img src="cnc-images/vcarve.png" style="border: 2px solid black;" />
    </p>
---

#### Assigning Cut/Pocket

Select the lines or shapes to define what will be cut or pocketed, then apply the relevant toolpath operation (profile/pocket).

---

#### 3. Toolpaths: Cut
  - Cuts along the outer or inner edge of a part.
  - Defines the final shape by following the contour
- Choose **Profile Toolpath**.
    <p align="center">
      <img src="cnc-images/cut.png" style="border: 2px solid black;" />
      </p>
- Set:
  - **Start Depth:** 0 mm
  - **Cut Depth:** 13 mm (12 mm material + 1 mm into sacrificial sheet)

- Specify Machine Vectors:
  - Select **Outside/Right** for vector machining to preserve size.
  - Select **Inside/Left** for cutting internal shapes or holes.
  - Select **On** for trimming directly along the vector line.

    <p align="center">
      <img src="cnc-images/cut2.png" style="border: 2px solid black;" />
      </p>

- Tool Settings (6 mm bit):
  - Spindle Speed: 8000 RPM
  - Feed Rate: 80 in/min
  - Plunge Rate: 15 in/min

    <p align="center">
      <img src="cnc-images/cut3.png" style="border: 2px solid black;" />
      </p>

- Specify the Number of Passes:
  - Press "Edit Passes"
    - Number of Passes: 2
      - First Pass Depth: 6.5mm
      - Second Pass Depth: 13mm

    <p align="center">
      <img src="cnc-images/pass.png" style="border: 2px solid black;" />
      </p>

- Click **Calculate**, then read the warnings, if it is within your expectations click **OK** to confirm.

    <p align="center">
      <img src="cnc-images/calculate.png" style="border: 2px solid black;" />
      </p>

    <p align="center">
      <img src="cnc-images/warning.png" style="border: 2px solid black;" />
      </p>

---

#### 4. Toolpaths: Pocket
  - Used to hollow out an internal region.
  - Useful for engravings or fitting one piece into another.
- Choose **Pocket Toolpath**.
      <p align="center">
        <img src="cnc-images/pocket.png" style="border: 2px solid black;" />
      </p>
- Set:
      <p align="center">
        <img src="cnc-images/pocket2.png" style="border: 2px solid black;" />
      </p>
  - **Start Depth:** 0.0 mm
  - **Cut Depth:** 2.0 mm
    - You can specify this value for engraving operations to achieve precise and consistent depth. 
- Recheck "Tool" Parameters:
      <p align="center">
        <img src="cnc-images/pocket3.png" style="border: 2px solid black;" />
      </p>
  - Press "Edit": 
    - Geometry:
      - Diameter: 6mm
    - Cutting Parameters:
      - Pass Depth: 6mm
      - Stepover: 4.002mm || 66.7%
    - Feeds and Speeds:
      - Spindle Speed: 8000 RPM
      - Feed Rate: 80 in/min
      - Plunge Rate: 15 in/min
    - Tool Number: 1
    - Press "OK"

#### Dogbone Fillet

  <iframe src="https://giphy.com/embed/Or8eV6iyuXgA9vTCIR" width="270" height="480" style="" frameBorder="0" class="giphy-embed" allowFullScreen></iframe><p><a href="https://giphy.com/gifs/Or8eV6iyuXgA9vTCIR"></a></p>

- Apply Dogbone Fillet to all internal corners used as joints
- Match radius to tool size (e.g., 3 mm radius for 6 mm bit)
- Allows square parts to fit snugly despite round tool paths
- Ensures clean, accurate assembly in CNC-milled joints


#### 5. Tabs
  - Small, uncut sections to keep parts attached to the sheet.
  - Prevents shifting or flying parts.
  - Size: Usually 3 mm wide and 2 mm high.
  - Automatically added in the Toolpath menu.
  - Best used manually to avoid tabs at the edges. 

---

#### 6. Preview Toolpaths
- Click on **Preview Toolpaths**.

  <p align="center">
      <img src="cnc-images/preview.png" style="border: 2px solid black;" />
      </p>

- In the drop-down, select **Preview Visible Toolpaths**.

  <p align="center">
      <img src="cnc-images/preview2.png" style="border: 2px solid black;" />
      </p>

- Go to the **3D View** tab.
- Click on **Toolpaths** in the top-right corner.

  <p align="center">
      <img src="cnc-images/preview3.png" style="border: 2px solid black;" />
      </p>

- Then do the following:
    <p align="center">
        <img src="cnc-images/preview4.png" style="border: 2px solid black;" />
      </p>
  - Manually lower the **Speed** setting.
  - Select **Reset Preview**.
  - In the **Toolpath List**, select the part to inspect.
  - Select **Preview Visible Toolpaths**.
    - If the toolpath preview appears erratic, the design may be *too small for the selected drill bit*.

    <p align="center">
      <img src="cnc-images/example.png" style="border: 2px solid black;" />
    </p>
    <p align="center"><em>Example</em></p>
- To fix this:

    <p align="center">
        <img src="cnc-images/preview5.png" style="border: 2px solid black;" />
      </p>

  - Return to the **Project** tab.
  - Resize the design by dragging from its edge.
    - Or adjust the design in your original software and re-export it.
- Back in the **Toolpath List**:

    <p align="center">
        <img src="cnc-images/preview6.png" style="border: 2px solid black;" />
      </p>

  - Double-click the part to re-inspect.
  - Scroll down and click **Calculate**.
    - If the toolpath still appears irregular, repeat the adjustment steps above.

#### 7. Changing the Drill Bit  
- For a better understanding, watch the first video on this page starting at 14:40.
- Turn off the CNC machine using the key (located at the bottom right) and remove it.

  <p align="center">
      <img src="cnc-images/preview7.png" style="border: 2px solid black;" />
      </p>

- Use two wrenches to loosen the collet assembly. 

    <p align="center">
        <img src="cnc-images/preview8.png" style="border: 2px solid black;" />
      </p>

  - Hold both wrenches in one hand to stabilize, and twist the lower wrench to loosen the collet nut. 
- Remove the collet and clean both the collet and nut for a secure fit.

  <p align="center">
      <img src="cnc-images/preview9.png" style="border: 2px solid black;" />
      </p>

- Reinsert the collet into its housing.  
- Insert the new drill bit, leaving ~20 mm (or two fingers) exposed for cutting clearance.  
- Tighten the collet assembly firmly using both wrenches.  
- Reinsert the key, power on the machine, and re-calibrate the Z-axis.

#### 8. ShopBot 3 Setup
- After checking that every toolpath is using Tool 1, Click **Save**.

  <p align="center">
      <img src="cnc-images/save.png" style="border: 2px solid black;" />
      </p>

- Click **Save Toolpath(s) to File** -> save it as **all**
  <p align="center">
      <img src="cnc-images/save2.png" style="border: 2px solid black;" />
      </p>

- Open **ShopBot 3** software.

  <p align="center">
      <img src="cnc-images/1.png" style="border: 2px solid black;" />
      </p>

- Clip the wire to the collet nut or the spindle body of the CNC machine.
- Place the **metal calibration plate** on the surface of the sheet.

  <p align="center">
      <img src="cnc-images/2.png" style="border: 2px solid black;" />
      </p>

  <p align="center">
      <img src="cnc-images/3.png" style="border: 2px solid black;" />
      </p>


- Run the **Z-zeroing command** (machine lowers bit to touch the plate).

  <p align="center">
      <img src="cnc-images/4.png" style="border: 2px solid black;" />
      </p>
- A warning will pop-up, and press **OK**.

  <p align="center">
      <img src="cnc-images/ok.png" style="border: 2px solid black;" />
      </p>

- System detects contact and sets Z = 0.

  <iframe src="https://giphy.com/embed/hiA4oUAEYvE0RDByUW" width="480" height="269" style="" frameBorder="0" class="giphy-embed" allowFullScreen></iframe><p><a href="https://giphy.com/gifs/hiA4oUAEYvE0RDByUW"></a></p>

- After calibration, remove the clip and plate, then return them to their original location with the clip still attached to the plate. This ensures smooth CNC operation.

- Then, move the drill head to desired origin (corner of the sheet).
- Set:
  - **X = 0**
  - **Y = 0**


---

#### 9. Z-Axis Calibration

- Clip the wire to the collet nut or the spindle body of the CNC machine.
- Place the **metal calibration plate** on the surface of the sheet.
- Run the **Z-zeroing command** (machine lowers bit to touch the plate).
- System detects contact and sets Z = 0.
-  After calibration, remove the clip and plate, then return them to their original location with the clip still attached to the plate. This ensures smooth CNC operation.

---

#### 10. Start Machining

- Click **Start** to begin the operation.
- Monitor the machine continuously.
- Do not touch or adjust material until the machine is fully stopped.
- After cutting completes, remove remaining debris.

![Insert cutting process image here](insert_image_path_here)

---