# 🔲 How to Use the Laser Cutting Machine  

*(This page provides step-by-step instructions for students on how to prepare and operate the laser cutter. Insert images where noted to enhance clarity and guidance.)*

---

#### 1️⃣ Preparing the File  
**Software: SolidWorks / Illustrator / CorelDraw / etc.**

- Export the design as a **DXF (.dxf)** file.  
- Send the file to the designated **email account** `fablabbh.share@gmail.com`.  
- On the laser cutting computer, **download** the file and **import it into RDWorks**.

---

#### 2️⃣ Setting Up in RDWorks  
📌 *Insert screenshot of RDWorks interface here*

- **Arrange the parts** on the virtual sheet using directional arrow buttons.  
- **Assign colors** to each part depending on whether it’s for cutting, engraving, or marking.  
- **Double-click the selected color** from the left color bar to adjust settings:
  - Input appropriate **Speed** and **Power** values based on material type and thickness.
  - Alternatively, use **Parameter Library** to select preconfigured material profiles.

✅ After setting all values, click **“Download”** to transfer the file to the machine.

---

#### 3️⃣ Operating the Laser Cutter  
📌 *Insert image of laser cutter with labeled parts here*

1. **Turn on** the machine and main power switch.  
2. **Insert the material** (e.g., 3mm plywood, 6mm acrylic).  
3. Flip the **light knob** to activate internal lighting.  
4. On the machine panel:  
   - Press **“File”** and select the file  
   - Press **“Enter”** to load it into memory  
5. Use **arrow keys** to move the laser head to the desired starting point.  
6. Adjust the **Z-axis** (height) of the laser:
   - Use a **spacer tool** (e.g., LEGO brick) for low thickness.
   - For thicker materials, keep around **2mm distance** between the laser head and the material.  
7. Press **“Origin”** to set the starting position.  
8. Press **“Frame”** to preview the cutting boundary.  
9. Once confirmed, press **“Start”** to begin cutting.

---

#### 🛡️ Safety & Efficiency Tips  
📌 *Insert image of safety guidelines and PPE here*

- Always wear **safety goggles** during operation.  
- Never leave the machine **unattended** while it's running.  
- Use **tape or weights** to hold down curled or uneven sheets.  
- Use **Frame preview** to avoid cutting beyond the material area.  
- **Organize parts efficiently** on the sheet to reduce material waste.

---

#### ✍️ Engraving Notes

- Use **lower power and higher speed** for engraving.  
- Perform a **small test area** first to avoid burning the material.  
- Ensure the surface is flat and clean for consistent engraving quality.

---

#### 🧪 Cutting Efficiency Test Example  
📌 *Insert photo of test squares with labels*

**Objective:**  
Determine the optimal speed and power settings for clean cuts on 2.45mm plywood without manual force.

---

**Test Parameters:**

- **Speeds (mm/s):** 15, 20, 30, 40  
- **Powers (%):** 15, 27, 40, 52, 65  

⚠️ *Do not exceed 70% power. It may damage the machine.*

---

**Successful Cutting Combinations:**

| Speed (mm/s) | Power (%) |
|--------------|------------|
| 15           | 40         |
| 20           | 30         |
| 10           | 52         |
| 20           | 52         |
| 30           | 52         |
| 15           | 65         |
| 20           | 65         |
| 30           | 65         |
| 40           | 65         |

---

**Conclusion:**  
Higher power settings (52–65%) combined with moderate to low speeds produced clean cuts. This combination allows the laser sufficient energy and time to fully penetrate the material without excessive scorching.

---

#### 🔍 Focal Point Experiment  
📌 *Insert photo of inclined test setup with cuts*

**Objective:**  
Understand how varying the laser's focal height (Z-axis) affects the quality of cuts.

---

**Setup:**

- A wooden plate was placed at an **inclined angle** on the cutting bed.  
- The laser cut along the slope, testing multiple focal heights.  

---

**Observations:**

- When **too far**, the beam was unfocused, producing wide and burnt edges.  
- When **too close**, the beam was concentrated but often failed to cut through fully.  
- The **ideal distance** created precise, clean lines without burn marks.  

---

**Conclusion:**  
The laser’s **focal point** plays a crucial role in cut quality. Proper Z-axis alignment ensures effective energy concentration, minimizing burns and maximizing precision.

---

#### 📎 Add Barcode Below  
📌 *Insert a QR code here that links directly to this documentation page on your website*

---